@@ -864,8 +864,8 @@ class CfnBudgetsAction(
         definition: typing.Union[aws_cdk.core.IResolvable, "CfnBudgetsAction.DefinitionProperty"],
         execution_role_arn: builtins.str,
         notification_type: builtins.str,
+        subscribers: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnBudgetsAction.SubscriberProperty"]]],
         approval_model: typing.Optional[builtins.str] = None,
-        subscribers: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnBudgetsAction.SubscriberProperty"]]]] = None,
     ) -> None:
         '''Create a new ``AWS::Budgets::BudgetsAction``.
 
@@ -877,8 +877,8 @@ class CfnBudgetsAction(
         :param definition: ``AWS::Budgets::BudgetsAction.Definition``.
         :param execution_role_arn: ``AWS::Budgets::BudgetsAction.ExecutionRoleArn``.
         :param notification_type: ``AWS::Budgets::BudgetsAction.NotificationType``.
-        :param approval_model: ``AWS::Budgets::BudgetsAction.ApprovalModel``.
         :param subscribers: ``AWS::Budgets::BudgetsAction.Subscribers``.
+        :param approval_model: ``AWS::Budgets::BudgetsAction.ApprovalModel``.
         '''
         props = CfnBudgetsActionProps(
             action_threshold=action_threshold,
@@ -887,8 +887,8 @@ class CfnBudgetsAction(
             definition=definition,
             execution_role_arn=execution_role_arn,
             notification_type=notification_type,
-            approval_model=approval_model,
             subscribers=subscribers,
+            approval_model=approval_model,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -1018,6 +1018,24 @@ class CfnBudgetsAction(
     def notification_type(self, value: builtins.str) -> None:
         jsii.set(self, "notificationType", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="subscribers")
+    def subscribers(
+        self,
+    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnBudgetsAction.SubscriberProperty"]]]:
+        '''``AWS::Budgets::BudgetsAction.Subscribers``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-budgets-budgetsaction.html#cfn-budgets-budgetsaction-subscribers
+        '''
+        return typing.cast(typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnBudgetsAction.SubscriberProperty"]]], jsii.get(self, "subscribers"))
+
+    @subscribers.setter
+    def subscribers(
+        self,
+        value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnBudgetsAction.SubscriberProperty"]]],
+    ) -> None:
+        jsii.set(self, "subscribers", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="approvalModel")
     def approval_model(self) -> typing.Optional[builtins.str]:
@@ -1031,24 +1049,6 @@ class CfnBudgetsAction(
     def approval_model(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "approvalModel", value)
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="subscribers")
-    def subscribers(
-        self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnBudgetsAction.SubscriberProperty"]]]]:
-        '''``AWS::Budgets::BudgetsAction.Subscribers``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-budgets-budgetsaction.html#cfn-budgets-budgetsaction-subscribers
-        '''
-        return typing.cast(typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnBudgetsAction.SubscriberProperty"]]]], jsii.get(self, "subscribers"))
-
-    @subscribers.setter
-    def subscribers(
-        self,
-        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnBudgetsAction.SubscriberProperty"]]]],
-    ) -> None:
-        jsii.set(self, "subscribers", value)
-
     @jsii.data_type(
         jsii_type="@aws-cdk/aws-budgets.CfnBudgetsAction.ActionThresholdProperty",
         jsii_struct_bases=[],
@@ -1444,8 +1444,8 @@ class CfnBudgetsAction(
         "definition": "definition",
         "execution_role_arn": "executionRoleArn",
         "notification_type": "notificationType",
-        "approval_model": "approvalModel",
         "subscribers": "subscribers",
+        "approval_model": "approvalModel",
     },
 )
 class CfnBudgetsActionProps:
@@ -1458,8 +1458,8 @@ class CfnBudgetsActionProps:
         definition: typing.Union[aws_cdk.core.IResolvable, CfnBudgetsAction.DefinitionProperty],
         execution_role_arn: builtins.str,
         notification_type: builtins.str,
+        subscribers: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, CfnBudgetsAction.SubscriberProperty]]],
         approval_model: typing.Optional[builtins.str] = None,
-        subscribers: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, CfnBudgetsAction.SubscriberProperty]]]] = None,
     ) -> None:
         '''Properties for defining a ``AWS::Budgets::BudgetsAction``.
 
@@ -1469,8 +1469,8 @@ class CfnBudgetsActionProps:
         :param definition: ``AWS::Budgets::BudgetsAction.Definition``.
         :param execution_role_arn: ``AWS::Budgets::BudgetsAction.ExecutionRoleArn``.
         :param notification_type: ``AWS::Budgets::BudgetsAction.NotificationType``.
-        :param approval_model: ``AWS::Budgets::BudgetsAction.ApprovalModel``.
         :param subscribers: ``AWS::Budgets::BudgetsAction.Subscribers``.
+        :param approval_model: ``AWS::Budgets::BudgetsAction.ApprovalModel``.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-budgets-budgetsaction.html
         '''
@@ -1481,11 +1481,10 @@ class CfnBudgetsActionProps:
             "definition": definition,
             "execution_role_arn": execution_role_arn,
             "notification_type": notification_type,
+            "subscribers": subscribers,
         }
         if approval_model is not None:
             self._values["approval_model"] = approval_model
-        if subscribers is not None:
-            self._values["subscribers"] = subscribers
 
     @builtins.property
     def action_threshold(
@@ -1551,6 +1550,18 @@ class CfnBudgetsActionProps:
         assert result is not None, "Required property 'notification_type' is missing"
         return typing.cast(builtins.str, result)
 
+    @builtins.property
+    def subscribers(
+        self,
+    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnBudgetsAction.SubscriberProperty]]]:
+        '''``AWS::Budgets::BudgetsAction.Subscribers``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-budgets-budgetsaction.html#cfn-budgets-budgetsaction-subscribers
+        '''
+        result = self._values.get("subscribers")
+        assert result is not None, "Required property 'subscribers' is missing"
+        return typing.cast(typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnBudgetsAction.SubscriberProperty]]], result)
+
     @builtins.property
     def approval_model(self) -> typing.Optional[builtins.str]:
         '''``AWS::Budgets::BudgetsAction.ApprovalModel``.
@@ -1560,17 +1571,6 @@ class CfnBudgetsActionProps:
         result = self._values.get("approval_model")
         return typing.cast(typing.Optional[builtins.str], result)
 
-    @builtins.property
-    def subscribers(
-        self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnBudgetsAction.SubscriberProperty]]]]:
-        '''``AWS::Budgets::BudgetsAction.Subscribers``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-budgets-budgetsaction.html#cfn-budgets-budgetsaction-subscribers
-        '''
-        result = self._values.get("subscribers")
-        return typing.cast(typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnBudgetsAction.SubscriberProperty]]]], result)
-
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
